Query Visual Studio setup for information on installed instances of Visual Studio.
This is a thin wrapper around the COM interface.
Consult the Microsoft.VisualStudio.Setup.Configuration documentation for more information on the API.
To use this library you must first initialize COM.
The helper, com::initialize will do this for you.
Example
use vssetup::{com, HRESULT, SetupConfiguration};
fn main() -> Result<(), HRESULT> {
com::initialize();
let setup = SetupConfiguration::new()?;
let instances = setup.EnumAllInstances()?;
for instance in instances {
let name = instance.GetDisplayName(0x400)?.to_string();
println!("{name}");
}
Ok(())
}Modules
- com
- Helpers for initailizing and uninitalizing COM.
Macros
Structs
- BSTR
- A BSTR string (BSTR) is a length-prefixed wide string.
- Enum
Setup Instances - FILETIME
- HRESULT
- An error code value returned by most COM functions.
- Safe
Array - An owned slice.
- Setup
Configuration - The entry point for these APIs.
- Setup
Error Info - Setup
Error State - Setup
Failed Package Reference - Setup
Instance - Setup
Instance Catalog - Setup
Package Reference - Setup
Product Reference - Setup
Property Store - WideStr